@@ -371,7 +371,7 @@ class Postgres(object):
             filter_list.append('"{}" = {}'.format(k, v))
         filter_str = 'where' + ' and '.join(filter_list) if filter_list else ''
         sql = "select {} from {} {}".format(columns_str, table, filter_str)
-        logger.info('sql:', sql)
+        logger.info('sql: %s' % sql)
         cursor.execute(sql)
         res = cursor.fetchall()
         cursor.close()
@@ -412,7 +412,7 @@ class Postgres(object):
             filter_list.append('"{}" = {}'.format(k, v))
         filter_str = 'where' + ' and '.join(filter_list) if filter_list else ''
         sql = "select {} from {} {}".format(columns_str, table, filter_str)
-        logger.info('sql:', sql)
+        logger.info('sql: %s' %sql)
         cursor.execute(sql)
         res = cursor.fetchone()
         cursor.close()
@@ -438,6 +438,9 @@ class Postgres(object):
         conn.close()
         return res
 
+    def close_connect(self):
+        pass
+
     @staticmethod
     def _format_str(line):
         # 指定字符替换为 -
@@ -445,3 +448,76 @@ class Postgres(object):
         # 指定字符去除
         line2 = re.sub(r"[‘’“”，。？?]", "", line1)
         return line2
+
+    def over_insert_df(self, df, table_name, text_column, date_columns=None):
+        conf = self.conf
+        conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+        cursor = conn.cursor()
+
+        c0 = df.columns.tolist()
+        data_list = df.values.tolist()
+        data_list.insert(0, c0)
+
+        if date_columns:
+            text_column.extend(date_columns)
+        cursor.execute(f'DROP TABLE IF EXISTS "{table_name}";')
+        count = 0
+        column_list = []
+
+        for row in data_list:
+            if count == 0:
+                # 标题format
+                column_list = [self._format_str(r) for r in row]
+
+                if not text_column:
+                    text_column = column_list
+                sql_str = ','.join([f'"{j.replace(" ", "_")}" float' if j not in text_column
+                                    else f'"{j.replace(" ", "_")}" text'
+                                    for j in column_list])
+                if not date_columns:
+                    date_columns = []
+                for dd in date_columns:
+                    sql_str = sql_str.replace(f'"{dd}" text', f'"{dd}" date')
+                # sql_s = re.findall(r'[^\*/:?\\|<>!]', sql_s, re.S)
+                # sql_s = "".join(sql_s)
+                # 自定义数据类型
+                if not self.is_table_exist(table_name):
+                    cursor.execute(f'create table {table_name} ({sql_str});')
+                    print('create table', sql_str)
+            else:
+                sql = f"INSERT INTO {table_name} VALUES ({','.join(['%s' for i in range(len(row))])})"
+                for i in range(len(row)):
+
+                    if date_columns and column_list[i] in date_columns:
+                        if isinstance(row[i], pd.Timestamp):
+                            row[i] = row[i].date()
+                        elif isinstance(row[i], str):
+                            row[i] = datetime.strptime(row[i], '%Y-%m-%d').date()
+                        elif isinstance(row[i], date):
+                            pass
+                        elif isinstance(row[i], datetime):
+                            row[i] = row[i].date()
+                        else:
+                            row[i] = None
+                    # print(type(row[i]),row[i])
+                    if row[i] == '' or (isinstance(row[i], float) and np.isnan(row[i])):
+                        row[i] = None
+                    # if filter_dict and column_list[i] in filter_dict.keys():
+                    #     if filter_dict[column_list[i]] == 'text_format':
+                    #         row_s = str(row[i])
+                    #         row_s = re.findall(r'[^\*/:?\\|<>!\-]', row_s, re.S)
+                    #         row[i] = "".join(row_s)
+
+                # one_sql_str = ','.join(row)
+                cursor.execute(sql, row)
+                # print(row)
+            count += 1
+
+        print(f'saved {table_name}')
+        conn.commit()
+        cursor.close()
+        conn.close()
\ No newline at end of file
